#' A Mapping from distribution names (inputs) to columns. This allows the
#' package to dynamically select column names for different distribution types.
#'
#' @docType data
#' @name distribution_column_mapping
#' @usage distribution_column_mapping
#' @format A data frame with 11 rows and 12 columns
#'
#' "distribution_column_mapping"

